@@ -40,10 +40,6 @@ AddConstraintActivitiesNotOverlappingForm::AddConstraintActivitiesNotOverlapping
 	connect(addAllActivitiesPushButton, SIGNAL(clicked()), this, SLOT(addAllActivities()));
 	connect(notOverlappingActivitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(removeActivity()));
 	connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
@@ -79,25 +75,17 @@ AddConstraintActivitiesNotOverlappingForm::AddConstraintActivitiesNotOverlapping
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 
 	notOverlappingActivitiesListWidget->clear();
 	notOverlappingActivitiesList.clear();
 
 	filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 AddConstraintActivitiesNotOverlappingForm::~AddConstraintActivitiesNotOverlappingForm()
@@ -110,13 +98,13 @@ bool AddConstraintActivitiesNotOverlappingForm::filterOk(Activity* act)
 	QString tn=teachersComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	int ok=true;
 
 	//teacher
 	if(tn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+		for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 			if(*it == tn){
 				ok2=true;
 				break;
@@ -130,13 +118,13 @@ bool AddConstraintActivitiesNotOverlappingForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+	if(atn!="" && !act->activityTagsNames.contains(atn))
 		ok=false;
 		
 	//students
 	if(stn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+		for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 			if(*it == stn){
 				ok2=true;
 				break;
@@ -149,11 +137,6 @@ bool AddConstraintActivitiesNotOverlappingForm::filterOk(Activity* act)
 }
 
 void AddConstraintActivitiesNotOverlappingForm::filterChanged()
-{
-	this->updateActivitiesListWidget();
-}
-
-void AddConstraintActivitiesNotOverlappingForm::updateActivitiesListWidget()
 {
 	activitiesListWidget->clear();
 	this->activitiesList.clear();
@@ -195,10 +178,9 @@ void AddConstraintActivitiesNotOverlappingForm::addConstraint()
 	}
 	
 	QList<int> ids;
-	int i;
-	QList<int>::iterator it;
+	QList<int>::const_iterator it;
 	ids.clear();
-	for(i=0, it=this->notOverlappingActivitiesList.begin(); it!=this->notOverlappingActivitiesList.end(); it++, i++){
+	for(it=this->notOverlappingActivitiesList.constBegin(); it!=this->notOverlappingActivitiesList.constEnd(); it++){
 		ids.append(*it);
 	}
 	
@@ -265,7 +247,7 @@ void AddConstraintActivitiesNotOverlappingForm::addAllActivities()
 void AddConstraintActivitiesNotOverlappingForm::removeActivity()
 {
 	if(notOverlappingActivitiesListWidget->currentRow()<0 || notOverlappingActivitiesListWidget->count()<=0)
-		return;		
+		return;
 	int tmp=notOverlappingActivitiesListWidget->currentRow();
 	
 	notOverlappingActivitiesList.removeAt(tmp);
