@@ -41,14 +41,10 @@ AddConstraintActivitiesOccupyMaxDifferentRoomsForm::AddConstraintActivitiesOccup
 	connect(addAllActivitiesPushButton, SIGNAL(clicked()), this, SLOT(addAllActivities()));
 	connect(selectedActivitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(removeActivity()));
 	connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 	
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
-							
+	
 	maxDifferentRoomsSpinBox->setMinimum(1);
 	maxDifferentRoomsSpinBox->setMaximum(MAX_ROOMS);
 	maxDifferentRoomsSpinBox->setValue(1);
@@ -85,25 +81,17 @@ AddConstraintActivitiesOccupyMaxDifferentRoomsForm::AddConstraintActivitiesOccup
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 
 	selectedActivitiesListWidget->clear();
 	selectedActivitiesList.clear();
 
 	filterChanged();
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 AddConstraintActivitiesOccupyMaxDifferentRoomsForm::~AddConstraintActivitiesOccupyMaxDifferentRoomsForm()
@@ -156,13 +144,13 @@ bool AddConstraintActivitiesOccupyMaxDifferentRoomsForm::filterOk(Activity* act)
 	QString tn=teachersComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	int ok=true;
 
 	//teacher
 	if(tn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+		for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 			if(*it == tn){
 				ok2=true;
 				break;
@@ -176,13 +164,13 @@ bool AddConstraintActivitiesOccupyMaxDifferentRoomsForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+	if(atn!="" && !act->activityTagsNames.contains(atn))
 		ok=false;
 		
 	//students
 	if(stn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+		for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 			if(*it == stn){
 				ok2=true;
 				break;
@@ -195,11 +183,6 @@ bool AddConstraintActivitiesOccupyMaxDifferentRoomsForm::filterOk(Activity* act)
 }
 
 void AddConstraintActivitiesOccupyMaxDifferentRoomsForm::filterChanged()
-{
-	this->updateActivitiesListWidget();
-}
-
-void AddConstraintActivitiesOccupyMaxDifferentRoomsForm::updateActivitiesListWidget()
 {
 	allActivitiesListWidget->clear();
 	this->activitiesList.clear();
