@@ -37,8 +37,6 @@ AddConstraintStudentsMaxBuildingChangesPerDayForm::AddConstraintStudentsMaxBuild
 	maxChangesSpinBox->setMinimum(0);
 	maxChangesSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxChangesSpinBox->setValue(1);
-	
-	constraintChanged();
 }
 
 AddConstraintStudentsMaxBuildingChangesPerDayForm::~AddConstraintStudentsMaxBuildingChangesPerDayForm()
@@ -46,10 +44,6 @@ AddConstraintStudentsMaxBuildingChangesPerDayForm::~AddConstraintStudentsMaxBuil
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintStudentsMaxBuildingChangesPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintStudentsMaxBuildingChangesPerDayForm::addCurrentConstraint()
 {
 	SpaceConstraint *ctr=NULL;
