@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <Qt>
+
 #include <QMessageBox>
 
 #include "tablewidgetupdatebug.h"
@@ -31,8 +33,6 @@
 #include <QBrush>
 #include <QColor>
 
-#include <QIcon>
-
 #define YES		(QString("X"))
 #define NO		(QString(" "))
 
@@ -100,11 +100,19 @@ AddConstraintStudentsSetNotAvailableTimesForm::~AddConstraintStudentsSetNotAvail
 void AddConstraintStudentsSetNotAvailableTimesForm::colorItem(QTableWidgetItem* item)
 {
 	if(USE_GUI_COLORS){
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+		if(item->text()==NO)
+			item->setBackground(QBrush(QColorConstants::DarkGreen));
+		else
+			item->setBackground(QBrush(QColorConstants::DarkRed));
+		item->setForeground(QBrush(QColorConstants::LightGray));
+#else
 		if(item->text()==NO)
 			item->setBackground(QBrush(Qt::darkGreen));
 		else
 			item->setBackground(QBrush(Qt::darkRed));
 		item->setForeground(QBrush(Qt::lightGray));
+#endif
 	}
 }
 
@@ -169,20 +177,6 @@ void AddConstraintStudentsSetNotAvailableTimesForm::setAllNotAvailable()
 void AddConstraintStudentsSetNotAvailableTimesForm::updateStudentsSetComboBox()
 {
 	populateStudentsComboBox(studentsComboBox);
-
-	/*studentsComboBox->clear();
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 }
 
 void AddConstraintStudentsSetNotAvailableTimesForm::itemClicked(QTableWidgetItem* item)
