@@ -46,8 +46,6 @@ AddConstraintTeacherMaxGapsPerDayForm::AddConstraintTeacherMaxGapsPerDayForm(QWi
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMaxGapsPerDayForm::~AddConstraintTeacherMaxGapsPerDayForm()
@@ -55,10 +53,6 @@ AddConstraintTeacherMaxGapsPerDayForm::~AddConstraintTeacherMaxGapsPerDayForm()
 	saveFETDialogGeometry(this);
 }
 
-void AddConstraintTeacherMaxGapsPerDayForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMaxGapsPerDayForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
