@@ -44,8 +44,6 @@ AddConstraintTeacherMaxHoursDailyForm::AddConstraintTeacherMaxHoursDailyForm(QWi
 		Teacher* tch=gt.rules.teachersList[i];
 		teachersComboBox->addItem(tch->name);
 	}
-
-	constraintChanged();
 }
 
 AddConstraintTeacherMaxHoursDailyForm::~AddConstraintTeacherMaxHoursDailyForm()
@@ -59,10 +57,6 @@ void AddConstraintTeacherMaxHoursDailyForm::updateMaxHoursSpinBox(){
 	maxHoursSpinBox->setValue(gt.rules.nHoursPerDay);
 }
 
-void AddConstraintTeacherMaxHoursDailyForm::constraintChanged()
-{
-}
-
 void AddConstraintTeacherMaxHoursDailyForm::addCurrentConstraint()
 {
 	TimeConstraint *ctr=NULL;
