@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <Qt>
+
 #include "longtextmessagebox.h"
 
 #include "alltimeconstraintsform.h"
@@ -159,7 +161,7 @@
 #include <QtAlgorithms>
 
 #include <algorithm>
-using namespace std;
+//using namespace std;
 
 extern const QString COMPANY;
 extern const QString PROGRAM;
