@@ -49,7 +49,7 @@ extern const QString PROGRAM;
 
 const int MAX_RECENT_FILES=10;
 
-class RandomSeedDialog: public QDialog
+/*class RandomSeedDialog: public QDialog
 {
 	Q_OBJECT
 	
@@ -76,7 +76,7 @@ public:
 public slots:
 	void help();
 	void ok();
-};
+};*/
 
 class FetMainForm: public QMainWindow, public Ui::FetMainForm_template
 {
@@ -124,7 +124,7 @@ public slots:
 	void on_fileNewAction_triggered();
 	void on_fileSaveAction_triggered();
 	void on_fileSaveAsAction_triggered();
-	void on_fileExitAction_triggered();
+	void on_fileQuitAction_triggered();
 	void on_fileOpenAction_triggered();
 	void on_fileClearRecentFilesListAction_triggered();
 	void openRecentFile();
