@@ -40,10 +40,6 @@ ModifyConstraintActivitiesSameStartingDayForm::ModifyConstraintActivitiesSameSta
 	connect(activitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(addActivity()));
 	connect(addAllActivitiesPushButton, SIGNAL(clicked()), this, SLOT(addAllActivities()));
 	connect(selectedActivitiesListWidget, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(removeActivity()));
-	connect(teachersComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(studentsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(subjectsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
-	connect(activityTagsComboBox, SIGNAL(activated(QString)), this, SLOT(filterChanged()));
 
 	connect(clearPushButton, SIGNAL(clicked()), this, SLOT(clear()));
 
@@ -83,22 +79,9 @@ ModifyConstraintActivitiesSameStartingDayForm::ModifyConstraintActivitiesSameSta
 	activityTagsComboBox->setCurrentIndex(0);
 
 	populateStudentsComboBox(studentsComboBox, QString(""), true);
-	/*studentsComboBox->addItem("");
-	for(int i=0; i<gt.rules.yearsList.size(); i++){
-		StudentsYear* sty=gt.rules.yearsList[i];
-		studentsComboBox->addItem(sty->name);
-		for(int j=0; j<sty->groupsList.size(); j++){
-			StudentsGroup* stg=sty->groupsList[j];
-			studentsComboBox->addItem(stg->name);
-			if(SHOW_SUBGROUPS_IN_COMBO_BOXES) for(int k=0; k<stg->subgroupsList.size(); k++){
-				StudentsSubgroup* sts=stg->subgroupsList[k];
-				studentsComboBox->addItem(sts->name);
-			}
-		}
-	}*/
 	studentsComboBox->setCurrentIndex(0);
 	
-	updateActivitiesListWidget();
+	filterChanged();
 	
 	weightLineEdit->setText(CustomFETString::number(ctr->weightPercentage));
 	
@@ -117,6 +100,11 @@ ModifyConstraintActivitiesSameStartingDayForm::ModifyConstraintActivitiesSameSta
 		assert(act);
 		selectedActivitiesListWidget->addItem(act->getDescription(gt.rules));
 	}
+
+	connect(teachersComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(studentsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(subjectsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
+	connect(activityTagsComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(filterChanged()));
 }
 
 ModifyConstraintActivitiesSameStartingDayForm::~ModifyConstraintActivitiesSameStartingDayForm()
@@ -129,13 +117,13 @@ bool ModifyConstraintActivitiesSameStartingDayForm::filterOk(Activity* act)
 	QString tn=teachersComboBox->currentText();
 	QString stn=studentsComboBox->currentText();
 	QString sbn=subjectsComboBox->currentText();
-	QString sbtn=activityTagsComboBox->currentText();
+	QString atn=activityTagsComboBox->currentText();
 	int ok=true;
 
 	//teacher
 	if(tn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+		for(QStringList::const_iterator it=act->teachersNames.constBegin(); it!=act->teachersNames.constEnd(); it++)
 			if(*it == tn){
 				ok2=true;
 				break;
@@ -149,13 +137,13 @@ bool ModifyConstraintActivitiesSameStartingDayForm::filterOk(Activity* act)
 		ok=false;
 		
 	//activity tag
-	if(sbtn!="" && !act->activityTagsNames.contains(sbtn))
+	if(atn!="" && !act->activityTagsNames.contains(atn))
 		ok=false;
 		
 	//students
 	if(stn!=""){
 		bool ok2=false;
-		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+		for(QStringList::const_iterator it=act->studentsNames.constBegin(); it!=act->studentsNames.constEnd(); it++)
 			if(*it == stn){
 				ok2=true;
 				break;
@@ -168,11 +156,6 @@ bool ModifyConstraintActivitiesSameStartingDayForm::filterOk(Activity* act)
 }
 
 void ModifyConstraintActivitiesSameStartingDayForm::filterChanged()
-{
-	updateActivitiesListWidget();
-}
-
-void ModifyConstraintActivitiesSameStartingDayForm::updateActivitiesListWidget()
 {
 	activitiesListWidget->clear();
 	this->activitiesList.clear();
@@ -212,9 +195,9 @@ void ModifyConstraintActivitiesSameStartingDayForm::ok()
 	}
 	
 	int i;
-	QList<int>::iterator it;
+	QList<int>::const_iterator it;
 	this->_ctr->activitiesId.clear();
-	for(i=0, it=this->selectedActivitiesList.begin(); it!=this->selectedActivitiesList.end(); it++, i++){
+	for(i=0, it=this->selectedActivitiesList.constBegin(); it!=this->selectedActivitiesList.constEnd(); it++, i++){
 		this->_ctr->activitiesId.append(*it);
 	}
 	this->_ctr->n_activities=i;
