@@ -44,8 +44,6 @@ ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm::ModifyConstraintStu
 	maxHoursSpinBox->setMinimum(1);
 	maxHoursSpinBox->setMaximum(gt.rules.nHoursPerDay);
 	maxHoursSpinBox->setValue(ctr->maxHoursContinuously);
-
-	constraintChanged();
 }
 
 ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm::~ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm()
@@ -65,12 +63,6 @@ void ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm::updateActivity
 	}
 	assert(j>=0);
 	activityTagsComboBox->setCurrentIndex(j);
-	
-	constraintChanged();
-}
-
-void ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm::constraintChanged()
-{
 }
 
 void ModifyConstraintStudentsActivityTagMaxHoursContinuouslyForm::ok()
