@@ -38,6 +38,12 @@
 #include <QDir>
 
 #include <QApplication>
+#include <QtGlobal>
+
+#include <QDate>
+#include <QTime>
+#include <QLocale>
+#include <QString>
 
 extern QMutex myMutex;
 
@@ -45,7 +51,7 @@ static GenerateMultipleThread generateMultipleThread;
 
 #include <QSemaphore>
 
-static QSemaphore semaphoreTimetableFinished; 
+static QSemaphore semaphoreTimetableFinished;
 
 static QSemaphore semaphoreTimetableStarted;
 
@@ -73,6 +79,8 @@ static time_t initial_time;
 extern int permutation[MAX_ACTIVITIES];
 int savedPermutation[MAX_ACTIVITIES];
 
+static int nGeneratedTimetables;
+
 void GenerateMultipleThread::run()
 {
 	genMulti.abortOptimization=false;
@@ -150,7 +158,7 @@ void GenerateMultipleThread::run()
 			
 			time_t finish_time;
 			time(&finish_time);
-			int seconds=int(finish_time-start_time);
+			int seconds=int(difftime(finish_time, start_time));
 			int hours=seconds/3600;
 			seconds%=3600;
 			int minutes=seconds/60;
@@ -243,15 +251,15 @@ void TimetableGenerateMultipleForm::help()
 	 " this might help.")
 	 +"\n\n"
 	 +tr("You can limit the search time, by specifying the maximum number of minutes allowed to spend for each timetable (option %1).").arg("'"+tr("Limit for each timetable")+"'")
-	 +" "+tr("The maximum and also the predefined value is %1 minutes, which means %2 hours, so virtually unlimited.").arg(60000).arg(1000)
+	 +" "+tr("The maximum and also the predefined value is %1 minutes, which means %2 hours, so virtually unlimited.").arg(600000).arg(10000)
 	 ;
-	 
-	 LongTextMessageBox::largeInformation(this, tr("FET information"), s);
+	
+	LongTextMessageBox::largeInformation(this, tr("FET information"), s);
 }
 
 void TimetableGenerateMultipleForm::start(){
 	//closeAllTimetableViewDialogs();
-
+	
 	nTimetables=timetablesSpinBox->value();
 	assert(nTimetables>0);
 	timeLimit=60*minutesSpinBox->value(); //seconds
@@ -307,6 +315,8 @@ void TimetableGenerateMultipleForm::start(){
 	timetablesGroupBox->setDisabled(true);
 	closePushButton->setDisabled(true);
 
+	nGeneratedTimetables=0;
+
 	simulation_running_multi=true;
 
 	for(int qq=0; qq<gt.rules.nInternalActivities; qq++)
@@ -326,6 +336,8 @@ void TimetableGenerateMultipleForm::timetableStarted(int timetable)
 
 void TimetableGenerateMultipleForm::timetableGenerated(int timetable, const QString& description, bool ok)
 {
+	nGeneratedTimetables++;
+
 	TimetableExport::writeRandomSeed(this, timetable, false); //false represents 'before' state
 
 	QString s=QString("");
@@ -396,7 +408,7 @@ void TimetableGenerateMultipleForm::stop()
 
 	time_t final_time;
 	time(&final_time);
-	int sec=int(final_time-initial_time);
+	int sec=int(difftime(final_time, initial_time));
 	int h=sec/3600;
 	sec%=3600;
 	int m=sec/60;
@@ -404,9 +416,20 @@ void TimetableGenerateMultipleForm::stop()
 
 	s+=TimetableGenerateMultipleForm::tr("The results were saved in the directory %1").arg(QDir::toNativeSeparators(destDir));
 	s+="\n\n";
-	s+=tr("Total searching time: %1h %2m %3s").arg(h).arg(m).arg(sec);
+	s+=tr("Total searching time: %1h %2m %3s.").arg(h).arg(m).arg(sec);
 	
-	TimetableExport::writeReportForMultiple(this, QString("\n")+s, false);
+	QDate dat=QDate::currentDate();
+	QTime tim=QTime::currentTime();
+	QLocale loc(FET_LANGUAGE);
+	QString sTime=loc.toString(dat, QLocale::ShortFormat)+" "+loc.toString(tim, QLocale::ShortFormat);
+	QString ms2=QString("\n\n");
+	ms2+=TimetableGenerateMultipleForm::tr("This file was automatically generated by FET %1 on %2.",
+	 "%1 is the FET version, %2 is the date and time when this file was generated.").arg(FET_VERSION).arg(sTime);
+
+	if(nGeneratedTimetables>=1)
+		TimetableExport::writeReportForMultiple(this, QString("\n")+s+ms2, false);
+	else
+		TimetableExport::writeReportForMultiple(this, s+ms2, true);
 
 	QMessageBox::information(this, tr("FET information"), s);
 
@@ -439,7 +462,7 @@ void TimetableGenerateMultipleForm::simulationFinished()
 	
 	time_t final_time;
 	time(&final_time);
-	int s=int(final_time-initial_time);
+	int s=int(difftime(final_time, initial_time));
 	int h=s/3600;
 	s%=3600;
 	int m=s/60;
@@ -450,20 +473,35 @@ void TimetableGenerateMultipleForm::simulationFinished()
 	ms+=QString("\n\n");
 	ms+=TimetableGenerateMultipleForm::tr("The results were saved in the directory %1").arg(QDir::toNativeSeparators(destDir));
 	ms+=QString("\n\n");
-	ms+=TimetableGenerateMultipleForm::tr("Total searching time was %1h %2m %3s").arg(h).arg(m).arg(s);
-	
-	TimetableExport::writeReportForMultiple(this, QString("\n")+ms, false);
+	ms+=TimetableGenerateMultipleForm::tr("Total searching time was %1h %2m %3s.").arg(h).arg(m).arg(s);
 
-#ifndef Q_WS_QWS
+	QDate dat=QDate::currentDate();
+	QTime tim=QTime::currentTime();
+	QLocale loc(FET_LANGUAGE);
+	QString sTime=loc.toString(dat, QLocale::ShortFormat)+" "+loc.toString(tim, QLocale::ShortFormat);
+	QString ms2=QString("\n\n");
+	ms2+=TimetableGenerateMultipleForm::tr("This file was automatically generated by FET %1 on %2.",
+	 "%1 is the FET version, %2 is the date and time when this file was generated.").arg(FET_VERSION).arg(sTime);
+	
+	assert(nGeneratedTimetables>=1);
+	TimetableExport::writeReportForMultiple(this, QString("\n")+ms+ms2, false);
+
+//On Windows we do not beep for Qt >= 5.14.1, because the QMessageBox below beeps itself.
+//It would be better to test at runtime, not at compile time, but it is easier/safer this way.
+//(The alternative would be to develop a parser for the function qVersion(), but I am not sure it will always respect the exact format "vM.vm.vp".)
+//We test the macro Q_OS_WIN32 because on the old Qt 4 it is the only available macro from these three below,
+//Q_OS_WIN, Q_OS_WIN32, and Q_OS_WIN64 (which are available on Qt 5.14.1).
+#if (!defined(Q_OS_WIN) && !defined(Q_OS_WIN32) && !defined(Q_OS_WIN64)) || (QT_VERSION < QT_VERSION_CHECK(5,14,1))
 	QApplication::beep();
 #endif
 	
+	//Old comment below. From Qt 5.14.1 on Windows all QMessageBox-es emit a sound.
 	//Trick so that the message box will be silent (the only sound is thus the beep above).
-	QMessageBox msgBox(this);
+	/*QMessageBox msgBox(this);
 	msgBox.setWindowTitle(TimetableGenerateMultipleForm::tr("FET information"));
 	msgBox.setText(ms);
-	msgBox.exec();
-	//QMessageBox::information(this, TimetableGenerateMultipleForm::tr("FET information"), ms);
+	msgBox.exec();*/
+	QMessageBox::information(this, TimetableGenerateMultipleForm::tr("FET information"), ms);
 	
 	startPushButton->setEnabled(true);
 	stopPushButton->setDisabled(true);
@@ -476,7 +514,7 @@ void TimetableGenerateMultipleForm::activityPlaced(int na)
 {
 	time_t finish_time;
 	time(&finish_time);
-	int seconds=int(finish_time-start_time);
+	int seconds=int(difftime(finish_time, start_time));
 	int hours=seconds/3600;
 	seconds%=3600;
 	int minutes=seconds/60;
