@@ -23,6 +23,7 @@
 //maybe TODO: maybe use only HTML level 1 instead of 3? advantage: a bit speedup. disadvantage: no coloring
 
 #include <QtGlobal>
+#include <QSizePolicy>
 
 #include "timetableprintform.h"
 
@@ -869,7 +870,7 @@ void TimetablePrintForm::updateNamesList(){
 		RBTimeHorizontalDay->setDisabled(false);
 		RBTimeVerticalDay->setDisabled(false);
 	} else if(CBTables->currentIndex()==9){
-		QString name = tr("All activities");
+		QString name = tr("All students");
 		namesList->addItem(name);
 		QListWidgetItem* tmpItem=namesList->item(0);
 		tmpItem->setSelected(true);
@@ -888,7 +889,7 @@ void TimetablePrintForm::updateNamesList(){
 		RBTimeHorizontalDay->setDisabled(true);
 		RBTimeVerticalDay->setDisabled(true);
 	} else if(CBTables->currentIndex()==10){
-		QString name = tr("All activities");
+		QString name = tr("All teachers");
 		namesList->addItem(name);
 		QListWidgetItem* tmpItem=namesList->item(0);
 		tmpItem->setSelected(true);
