@@ -15,6 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <Qt>
+
 #include <QtGlobal>
 
 #include "tablewidgetupdatebug.h"
@@ -501,10 +503,17 @@ void TimetableViewRoomsDaysHorizontalForm::updateRoomsTimetableTable(){
 					QBrush bg(stringToColor(act->subjectName+" "+act->studentsNames.join(", ")));
 					roomsTimetableTable->item(j, k)->setBackground(bg);
 					double brightness = bg.color().redF()*0.299 + bg.color().greenF()*0.587 + bg.color().blueF()*0.114;
+#if QT_VERSION >= QT_VERSION_CHECK(5,14,0)
+					if (brightness<0.5)
+						roomsTimetableTable->item(j, k)->setForeground(QBrush(QColorConstants::White));
+					else
+						roomsTimetableTable->item(j, k)->setForeground(QBrush(QColorConstants::Black));
+#else
 					if (brightness<0.5)
 						roomsTimetableTable->item(j, k)->setForeground(QBrush(Qt::white));
 					else
 						roomsTimetableTable->item(j, k)->setForeground(QBrush(Qt::black));
+#endif
 				}
 				// add colors (end)
 				//end by Marco Vassura
@@ -542,7 +551,7 @@ QColor TimetableViewRoomsDaysHorizontalForm::stringToColor(QString s)
 	// CRC-24 Based on RFC 2440 Section 6.1
 	unsigned long crc = 0xB704CEL;
 	int i;
-	QChar *data = s.data();
+	QChar* data = s.data();
 	while (!data->isNull()) {
 		crc ^= (data->unicode() & 0xFF) << 16;
 		for (i = 0; i < 8; i++) {
